package com.zswl.cloud.springBtach.server.core.api.video2;

import com.eeext.openapi.Client;
import com.eeext.openapi.entity.*;
import com.zswl.cloud.springBtach.server.core.dao.ApiLogDao;
import com.zswl.cloud.springBtach.server.core.domain.ApiLog;
import lombok.SneakyThrows;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;

@Component
public class Video2Api {


    @Autowired
    ApiLogDao apiLogDao;

    @Value("${video2.merchantId}")
    private String merchantId;

    @Value("${video2.secretKey}")
    private String secretKey;
    // 是否为生产环境，false表示沙箱环境，true表示生产环境
    @Value("${video2.isProd}")
    private Boolean isProd;

    private Client client;

    @PostConstruct
    public void init() {
        client = new Client(merchantId, secretKey, isProd);
    }
    /**
     * 充值下单
     *
     * @param rechargeOrderReq
     */
    @SneakyThrows
    public RechargeOrderResp rechargeOrder(RechargeOrderReq rechargeOrderReq) {

        RechargeOrderResp resp = client.rechargeOrder(rechargeOrderReq);
// 第三步：判断CODE是否为下单成功。注意：有些接口需要判断api.CodeResponseSuccess，具体以接口详情为准
        if (resp.isSuccess()) {
            //...下单成功并不表示充值成功，需要在回调通知中判断订单状态
        }

        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("video2");
        apiLog.setRequest(rechargeOrderReq);
        apiLog.setResponse(resp);
        apiLog.setService("rechargeOrder");
        apiLogDao.save(apiLog);

        return resp;


    }


    /**
     * 直充订单查询接口
     *
     * @param outTradeNo
     * @return
     */
    @SneakyThrows
    public RechargeQueryResp rechargeQuery(String outTradeNo) {
        RechargeQueryResp rechargeQueryResp = client.rechargeQuery(outTradeNo);
// 第三步：判断CODE是否为下单成功。注意：有些接口需要判断api.CodeResponseSuccess，具体以接口详情为准
        if (rechargeQueryResp.isSuccess()) {
            //...下单成功并不表示充值成功，需要在回调通知中判断订单状态
        }
        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("video2");
        apiLog.setRequest(outTradeNo);
        apiLog.setResponse(rechargeQueryResp);
        apiLog.setService("rechargeQuery");
        apiLogDao.save(apiLog);
        return rechargeQueryResp;


    }

    /**
     * 卡密下单
     *
     * @param cardOrderReq
     * @return
     */
    @SneakyThrows
    public CardOrderResp cardOrder(CardOrderReq cardOrderReq) {
        CardOrderResp cardOrderResp = client.cardOrder(cardOrderReq);
// 第三步：判断CODE是否为下单成功。注意：有些接口需要判断api.CodeResponseSuccess，具体以接口详情为准
        if (cardOrderResp.isSuccess()) {
            //...下单成功并不表示充值成功，需要在回调通知中判断订单状态
        }
        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("video2");
        apiLog.setRequest(cardOrderReq);
        apiLog.setResponse(cardOrderResp);
        apiLog.setService("cardOrder");
        apiLogDao.save(apiLog);
        return cardOrderResp;


    }

    /**
     * 卡密下单查询
     *
     * @param outTradeNo
     * @return
     */
    @SneakyThrows
    public CardQueryResp cardQuery(String outTradeNo) {
        CardQueryResp cardQueryResp = client.cardQuery(outTradeNo);
// 第三步：判断CODE是否为下单成功。注意：有些接口需要判断api.CodeResponseSuccess，具体以接口详情为准
        if (cardQueryResp.isSuccess()) {
            //...下单成功并不表示充值成功，需要在回调通知中判断订单状态
        }

        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("video2");
        apiLog.setRequest(outTradeNo);
        apiLog.setResponse(cardQueryResp);
        apiLog.setService("cardOrder");
        apiLogDao.save(apiLog);
        return cardQueryResp;
    }

    /**
     * 卡密重发短信接口
     *
     * @param outTradeNo
     * @return
     */
    @SneakyThrows
    public CardIssueResp cardIssue(String outTradeNo) {
        CardIssueResp cardQueryResp = client.cardIssue(outTradeNo);
// 第三步：判断CODE是否为下单成功。注意：有些接口需要判断api.CodeResponseSuccess，具体以接口详情为准
        if (cardQueryResp.isSuccess()) {
            //...下单成功并不表示充值成功，需要在回调通知中判断订单状态
        }

        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("video2");
        apiLog.setRequest(outTradeNo);
        apiLog.setResponse(cardQueryResp);
        apiLog.setService("cardIssue");
        apiLogDao.save(apiLog);
        return cardQueryResp;
    }

    /**
     * 获取商品列表接口
     *
     * @return
     */
    @SneakyThrows
    public RechargeProductResp rechargeProduct() {
        RechargeProductResp rechargeProductResp = client.rechargeProduct();
// 第三步：判断CODE是否为下单成功。注意：有些接口需要判断api.CodeResponseSuccess，具体以接口详情为准
        if (rechargeProductResp.isSuccess()) {
            //...下单成功并不表示充值成功，需要在回调通知中判断订单状态
        }

        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("video2");
        apiLog.setResponse(rechargeProductResp);
        apiLog.setService("rechargeProduct");
        apiLogDao.save(apiLog);
        return rechargeProductResp;
    }

    /**
     * 余额查询接口
     *
     * @return
     */
    @SneakyThrows
    public RechargeInfoResp cardIssue() {
        RechargeInfoResp rechargeInfoResp = client.rechargeInfo();
// 第三步：判断CODE是否为下单成功。注意：有些接口需要判断api.CodeResponseSuccess，具体以接口详情为准
        if (rechargeInfoResp.isSuccess()) {
            //...下单成功并不表示充值成功，需要在回调通知中判断订单状态
        }

        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("video2");
        apiLog.setResponse(rechargeInfoResp);
        apiLog.setService("rechargeInfo");
        apiLogDao.save(apiLog);
        return rechargeInfoResp;
    }


}
